@@ -1,4 +1,4 @@
-use macroquad::prelude::*;
+use litequad::prelude::*;
 
 use crate::{LineType, Marker, Matrix, Plot};
 
@@ -158,9 +158,7 @@ pub async fn run(plot: Plot) {
             );
         }
 
-        if !plot.axis_desc.x_label.is_empty() {
-            
-            /* 
+        if !plot.axis_desc.x_label.is_empty() {      
             //let len = plot.axis_desc.y_label.len() as f32 * (YLABEL_SIZE / 4. - COORD_THICKNESS / 2.);
             for (idx, char) in plot.axis_desc.x_label.chars().into_iter().enumerate() {
                 let adding = if char == 'i' { 3. } else {0.};
@@ -174,7 +172,7 @@ pub async fn run(plot: Plot) {
                     std::f32::consts::PI / 2.
                 );  
             }
-            */
+            
         }
 
         let (subtract_x, subtract_y) = if !plot.axis_desc.y_label.is_empty()
